angular.module('starter.controllers', [])

.controller('AppCtrl', function($scope, $http, $ionicModal, $timeout) {

  // With the new view caching in Ionic, Controllers are only called
  // when they are recreated or on app start, instead of every page change.
  // To listen for when this page is active (for example, to refresh data),
  // listen for the $ionicView.enter event:
  //$scope.$on('$ionicView.enter', function(e) {
  //});

  // Form data for the login modal
  $scope.loginData = {};

  // Create the login modal that we will use later
  $ionicModal.fromTemplateUrl('templates/login.html', { scope: $scope }).then(function(modal) {
		$scope.modal = modal;
  });

  // Triggered in the login modal to close it
  $scope.closeLogin = function() {
		$scope.modal.hide();
  };

  // Open the login modal
  $scope.login = function() {
		if(window.localStorage.getItem("login") !== null) {
			$scope.doLogout();
		} else {
			$scope.msg = '';
			$scope.loginData.username = '';
			$scope.loginData.password = '';
			$scope.modal.show();
		}		
  };

  // Perform the login action when the user submits the login form
  $scope.doLogin = function() {
		console.log('Doing login', $scope.loginData);
			
		// send login data
		$http({
			method: 'POST',
			url: 'http://localhost:8080/SpringRestfulExample/customer/login',
			data: 'username='+$scope.loginData.username+'&password='+$scope.loginData.password,
			headers: {'Content-Type': 'application/x-www-form-urlencoded'}
		}).success(function (data, status, headers, config) {
			// handle success things
			console.log('AppCtrl doLogin success...', status);
			$scope.msg = 'Successful';
				
			//setting session here
			window.localStorage.setItem("login", $scope.loginData.username);
			$scope.loginout = "Logout"
			
			$scope.closeLogin();
		}).error(function (data, status, headers, config) {
			// handle error things
			console.log('AppCtrl doLogin error...', status);			
			$scope.msg = 'Failed';
		});
  };
  
  // Perform the logout action
  $scope.doLogout = function() {
		console.log('Doing logout');				
		$scope.loginout = "Login"
		window.localStorage.removeItem("login");
  };
  
	//Setting default one
	if(window.localStorage.getItem("login") !== null) {
		$scope.loginout = "Logout"
	} else {
		$scope.loginout = "Login"
	}  
})

.controller('HomeController', function($scope, $http, $stateParams) {
	$scope.getData = function() {
		$http.get("http://localhost:8080/SpringRestfulExample/company")
		.success(function(data, status) {		
			$scope.name = data[0].name;
			$scope.background = data[0].background;
		})
		.error(function(data, status) {
			console.log('HomeController Error...', status);
		});
    };
	
	$scope.getData();
})

.controller('ShopListsController', function($scope, $http, $stateParams) {
	$scope.getData = function() {
		$http.get("http://localhost:8080/SpringRestfulExample/shop")
		.success(function(data, status) {		
			$scope.shoplists = data;
		})
		.error(function(data, status) {
			console.log('ShopListsController Error...', status);
		});
    };
	
	$scope.getData();
})

.controller('ShopController', function($scope, $http, $stateParams) {
	$scope.getData = function() {
		$http.get("http://localhost:8080/SpringRestfulExample/shop/"+$stateParams.shopId)
		.success(function(data, status) {		
			$scope.shop = data;
			
			var myLatlng = new google.maps.LatLng($scope.shop.mapLatitude,$scope.shop.mapLongitude);
			var mapOptions = {
				center: myLatlng,
				zoom: 14,
				mapTypeId: google.maps.MapTypeId.ROADMAP
			};
			var map = new google.maps.Map(document.getElementById("map"), mapOptions);
			var marker = new google.maps.Marker({
				position: myLatlng,
				map: map,
				title: $scope.shop.name
			});
			google.maps.event.addListener(marker, 'click', function() {
				infowindow.open(map,marker);
			});
			$scope.map = map;
		})
		.error(function(data, status) {
			console.log('ShopController Error...', status);
		});
    };
	
	$scope.getData();
})

.controller('ProductListsController', function($scope, $http, $stateParams) {
	
	$scope.getData = function() {
		$http.get("http://localhost:8080/SpringRestfulExample/product")
		.success(function(data, status) {		
			$scope.productlists = data;
		})
		.error(function(data, status) {
			console.log('ProductListsController getData Error...', status);
		});
    };
	$scope.search = function() {
		var key = angular.element(query).scope().query;
		var length = key.length;

		//Action when query length >= 3
		if(length >= 3) {
			$http.get("http://localhost:8080/SpringRestfulExample/product/q/"+key)
			.success(function(data, status) {		
				$scope.productlists = data;
			})
			.error(function(data, status) {
				console.log('ProductListsController search Error...', status);
			});
		} else {
			$scope.getData();	
		}
    };
  
	$scope.getData();
})

.controller('ProductController', function($scope, $http, $stateParams) {
	$scope.getData = function() {
		$http.get("http://localhost:8080/SpringRestfulExample/product/"+$stateParams.productId)
		.success(function(data, status) {
			$scope.product = data;
		})
		.error(function(data, status) {
			console.log('ProductController Error...', status);
		});
    };
	
	$scope.getData();
})

.controller('PromotionListsController', function($scope, $http, $stateParams) {
	
	$scope.getData = function() {
		$http.get("http://localhost:8080/SpringRestfulExample/promotion")
		.success(function(data, status) {		
			$scope.promotionlists = data;
		})
		.error(function(data, status) {
			console.log('PromotionListsController getData Error...', status);
		});
    };
  
	$scope.getData();
})

.controller('PromotionController', function($scope, $http, $stateParams) {
	$scope.getData = function() {
		$http.get("http://localhost:8080/SpringRestfulExample/promotion/"+$stateParams.promotionId)
		.success(function(data, status) {
			$scope.promotion = data;
		})
		.error(function(data, status) {
			console.log('PromotionController Error...', status);
		});
    };
	
	$scope.getData();
})

;
